@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: benchmark.pl,v 1.1 1999/10/13 15:02:54 tai Exp $
+# $Id: benchmark.pl,v 1.2 1999/10/24 13:31:55 tai Exp $
 #
 # Simple script to compare speed of Text::Template and this module.
 #
@@ -14,23 +14,29 @@ name: { $name }
 type: { $type }
 EOF
 
-$text = $text x 2048;
+$text = $text x 1024;
 $name = 'foobar';
 $type = 'string';
 
 timethese(10, {
-    'old' => \&oldfunc,
-    'new' => \&newfunc,
+    'Builtin::Eval'        => \&func_00,
+    'Text::SimpleTemplate' => \&func_01,
+    'Text::Template'       => \&func_02,
 });
 
 exit(0);
 
-sub oldfunc {
-    $tmpl = new Text::Template(TYPE => 'STRING', SOURCE => $text);
-    $tmpl->fill_in(DELIMITERS => [qw({ })]);
+sub func_00 {
+    $tmpl = $text;
+    $tmpl =~ s/{(.*?)}/eval($1)/ge;
 }
 
-sub newfunc {
+sub func_01 {
     $tmpl = new Text::SimpleTemplate;
     $tmpl->pack($text, LR_CHAR => [qw({ })])->fill;
 }
+
+sub func_02 {
+    $tmpl = new Text::Template(TYPE => 'STRING', SOURCE => $text);
+    $tmpl->fill_in(DELIMITERS => [qw({ })]);
+}
